CoreInitializeResponse class

Constructors

CoreInitializeResponse({required String name, required CoreFirebaseOptions options, bool? isAutomaticDataCollectionEnabled, required Map<String?, Object?> pluginConstants})

Properties

hashCode → int
The hash code for this object.
no setteroverride
isAutomaticDataCollectionEnabled ↔ bool?
getter/setter pair
name ↔ String
getter/setter pair
options ↔ CoreFirebaseOptions
getter/setter pair
pluginConstants ↔ Map<String?, Object?>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → CoreInitializeResponse