TestBinaryMessenger class
The subset of flutter_test's TestDefaultBinaryMessenger that generated
Pigeon test APIs rely on.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setMockDecodedMessageHandler<
T> (BasicMessageChannel< T> channel, Future<T> handler(T? message)?) → void -
Intercepts messages sent on
channel, decoding them with the channel's codec before handing them tohandler. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited